# Copyright (C) 1999, 2000 Jay Beale
# Licensed under the GNU General Public License

package Bastille::SecureInetd;

use Bastille::API;
@ENV="";
$ENV{PATH}="";
$ENV{CDPATH}=".";
$ENV{BASH_ENV}="";


#### TO DO:  Completely change what we do here...  DonW's suggestion?



#######################################################################
##                    inetd / TCP Wrappers Configuration             ##
#######################################################################

&ModifyInetdconf;
&CreateBanners;


sub ModifyInetdconf {

# uncomment pop3,imap,tftpd and in.bootpd ; the latter two are used
# specifically as "booby traps" to better log scans
# further, comment the (default non-tcp wrapped) linuxconf

   if ($GLOBAL_CONFIG{"SecureInetd"}{"modifyinetd"} eq "Y") {

       &ActionLog("# sub ModifyInetdconf\n");
 
       &B_hash_uncomment_line ("/etc/inetd.conf","pop-3");
       &B_hash_uncomment_line ("/etc/inetd.conf","imap");
       &B_hash_uncomment_line ("/etc/inetd.conf","tftp");
       &B_hash_uncomment_line ("/etc/inetd.conf","bootpd");
       &B_hash_comment_line ("/etc/inetd.conf","linuxconf");

       # Default ssh: allow all IP's.
       my $ssh_allowed_hosts="ALL";

       if ($GLOBAL_CONFIG{"SecureInetd"}{"limit_ssh"} eq "Y") {

	   # If the range isn't written, just set it to ALL
	   unless ($GLOBAL_CONFIG{"SecureInetd"}{"limit_ssh_range"}) {
	       $ssh_allowed_hosts="ALL";
	   }
	   else {

	       # Add localhost to the ssh range if it's not there...
	       $ssh_allowed_hosts=$GLOBAL_CONFIG{"SecureInetd"}{"limit_ssh_range"};
	       unless ($ssh_allowed_hosts =~ /127\.0\.0\.1/) {
		   $ssh_allowed_hosts="$ssh_allowed_hosts 127.0.0.1";
	       }
	   }
      }

       # Replace entire hosts.allow file

       my $hosts_allow_file = <<END_HOSTS_ALLOW;
#
# hosts.allow   This file describes the names of the hosts which are
#               allowed to use the local INET services, as decided
#               by the '/usr/sbin/tcpd' server.
#

# Bastille modifications made below...
	    
# Let everyone ssh here.
sshd: $ssh_allowed_hosts : ALLOW

# TELNET: Please be advised that telnet is a rather dangerous protocol.
#         All usernames/passwords used in remote sessions via telnet can
#         be seen by many other computers between them.  In fact, most
#         ethernet configurations allow every other computer on your 
#         local area network to see the entire session, passwords and all.
#         Further, there are utilities (like Hunt) in wide use that allow
#         one of these hosts to take over your telnet session.
#         
#         There is a much safer facility that allows for remote logins,
#         which is installed on your box, called ssh.  To use it, type:
#
#                 ssh username\@targethost 
#
#         Please don't uncomment the line below...

#in.telnetd: ALL : banners /etc/banners : ALLOW

# FTP:    Please be advised that ftp is a rather dangerous protocol.
#         All usernames/passwords used in remote sessions via ftp can
#         be seen by many other computers between them.  In fact, most
#         ethernet configurations allow every other computer on your 
#         local area network to see the entire session, passwords and all.
#
#         There is a much safer facility that allows for remote copies,
#         which is installed on your box, called scp.  To use it, read a
#         bit by typing 
#
#                       man scp
#
#         In essence, it works much like "cp," but with remote sources/targets.
#         For example,  scp jay\@zark.umuc.edu:/etc/hosts /etc/hosts
#
#
#         Please don't uncomment the line below...

#in.ftpd: ALL : banners /etc/banners : ALLOW

# POP3/:   You can allow pop3/imapd, but it is highly recommended that you
# IMAPD:   look into a secure version that does not transmit names/passwords
#          in cleartext.  Please consider doing this before you uncomment the
#          lines below:

#ipop3d: ALL : ALLOW
#imapd:  ALL : ALLOW


# Set a default deny stance with back finger "booby trap" (Venema's term)
# Allow finger to prevent deadly finger wars, whereby another booby trapped
# box answers our finger with its own, spawning another from us, ad infinitum

in.fingerd: ALL : ALLOW

ALL : ALL : spawn (/usr/sbin/safe_finger -l @%h | /bin/mail root) & : DENY

END_HOSTS_ALLOW

       &B_blank_file ("/etc/hosts.allow");
       &B_append_line ("/etc/hosts.allow","Bastille",$hosts_allow_file);


   }
}

sub CreateBanners {

    if ($GLOBAL_CONFIG{"SecureInetd"}{"banners"} eq "Y") {

	my $distro = &GetDistro;

	if ( ($distro =~ /^RH/) or ($distro =~ /^MN/) ) {

	    # Create banners for telnet/ftp...

	    &ActionLog("# sub CreateBanners\n");
       
	    &B_create_dir ("/etc/banners");
	    &B_chmod ("/etc/banners",0744);

	    unless ($GLOBAL_LOGONLY) {
		&B_cp("/usr/doc/tcp_wrappers-7.6/Banners.Makefile","/etc/banners/Makefile");
	    }

	    &B_create_file("/etc/banners/prototype");


	    my $banner_line = <<ENDBANNER;

***************************************************************************
                            NOTICE TO USERS
			    
			    
This is computer system is for authorized use only. Users (authorized or
unauthorized) have no explicit or implicit expectation of privacy.
			    
Any or all uses of this system and all files on this system may be
intercepted, monitored, recorded, copied, audited, inspected, and disclosed to
authorized site and law enforcement personnel.

By using this system, the user consents to such interception, monitoring,
recording, copying, auditing, inspection, and disclosure at the discretion of
authorized site.

Unauthorized or improper use of this system may result in administrative
disciplinary action and civil and criminal penalties. By continuing to use
this system you indicate your awareness of and consent to these terms and
conditions of use. LOG OFF IMMEDIATELY if you do not agree to the conditions
stated in this warning.

*****************************************************************************

ENDBANNER

            &B_append_line("/etc/banners/prototype","NOTICE",$banner_line);
	    &B_append_line("/etc/motd","NOTICE",$banner_line);

	}
   }   
}


1;

